# Copyright 2008-2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
# For further info, check  http://launchpad.net/filesync-server

"""Django settings for filesync project.

Generated by 'django-admin startproject' using Django 1.8.2.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.8/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
import urllib


def get_postgres_uri(store_settings):
    """Return a postgres connection uri."""
    db_name = store_settings['NAME']
    host = urllib.quote(store_settings['HOST'], safe='')
    port = store_settings['PORT']
    username = store_settings['USER']
    password = store_settings['PASSWORD']
    if password:
        password = ':' + password
    uri = 'postgres://'
    if username:
        uri += '%s%s@' % (username, password)
    uri += '%s:%s/%s' % (host, port, db_name)
    return uri


def get_file_content(folder, filename):
    filepath = os.path.join(folder, filename)
    if not os.path.exists(filepath):
        filepath = os.path.join(folder, 'dev-' + filename)

    with open(filepath) as f:
        content = f.read()

    return content


BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '%kj2ks+76)v=*@@wbz&b&fe8k$aax41q+6dy((q684uh#ttwa%'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',
    'django_openid_auth',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',
)

ROOT_URLCONF = 'filesync.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'filesync.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.8/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'filesync',
        'HOST': '/dev/shm/pg_filesync',
        'PORT': 5432,
        'USER': 'postgres',
        'PASSWORD': '',
    },
    'filesync': {
        'ENGINE': 'storm.django.backend',
        'NAME': 'filesync',
        'HOST': '/dev/shm/pg_filesync',
        'PORT': 5432,
        'USER': 'postgres',
        'PASSWORD': '',
    },
}

DATABASE_ENGINE = DATABASES['default']['ENGINE']
DATABASE_NAME = DATABASES['default']['NAME']
DATABASE_DEFAULTS = DATABASES['default']
DATABASE_USER = DATABASES['default']['USER']
DATABASE_PASSWORD = ''
DATABASE_HOST = ''
DATABASE_PORT = ''
STORM_STORES = {
    'filesync': get_postgres_uri(DATABASES['filesync']),
}


# Internationalization
# https://docs.djangoproject.com/en/1.8/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = False


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.8/howto/static-files/

STATIC_URL = '/static/'


# Custom settings

API_SERVER_CERTS_FOLDER = os.path.join(BASE_DIR, 'certs')
# the `api_server_crt` key with the content of `cacert.pem` file
API_SERVER_CRT = get_file_content(API_SERVER_CERTS_FOLDER, 'cacert.pem')
API_SERVER_CRT_CHAIN = None
# the `api_server_key` key with the content of `privkey.pem` file
API_SERVER_KEY = get_file_content(API_SERVER_CERTS_FOLDER, 'privkey.pem')
API_SERVER_DELTA_MAX_SIZE = 1000
API_SERVER_GC_DEBUG = True
API_SERVER_GET_FROM_SCRATCH_LIMIT = 2000
API_SERVER_GRACEFUL_SHUTDOWN = True
API_SERVER_HEARTBEAT_INTERVAL = 5
API_SERVER_IDLE_TIMEOUT = 7200
API_SERVER_LOGGER_NAME = 'storage.server'
API_SERVER_LOG_FILENAME = 'filesync-server.log'
API_SERVER_MAGIC_UPLOAD_ACTIVE = True
API_SERVER_MAX_DELTA_INFO = 20
API_SERVER_METRICS_NAMESPACE = 'development.filesync.server'
API_SERVER_MULTIPART_THRESHOLD = 10485760
API_SERVER_PROTOCOL_WEAKREF = False
API_SERVER_S3_BUCKET = 'test'
API_SERVER_S3_FALLBACK_BUCKET = None
API_SERVER_S3_RETRIES = 2
API_SERVER_S3_RETRY_WAIT = 0.1
API_SERVER_SERVERNAME = 'filesyncserver-development'
API_SERVER_SLI_METRIC_NAMESPACE = None
API_SERVER_STATS_LOG_INTERVAL = 0
API_SERVER_STATUS_PORT = 21102
API_SERVER_STORAGE_CHUNK_SIZE = 5242880
API_SERVER_TCP_PORT = 21100
API_SERVER_TRACE_USERS = ['test', 'etc']
API_SERVER_UPLOAD_BUFFER_MAX_SIZE = 10485761

AWS_ACCESS_KEY_ID = 'aws_key'
AWS_SECRET_ACCESS_KEY = 'aws_secret'
AWS_S3_HOST = 's3.local'
AWS_S3_PORT = 0
AWS_S3_PROXY_HOST = 'None'
AWS_S3_PROXY_PORT = 'None'
AWS_S3_USE_SSL = False

GENERAL_APP_NAME = 'filesync'
GENERAL_ENVIRONMENT_NAME = 'development'
GENERAL_INSTANCE_ID = 1
GENERAL_LOG_FOLDER = 'tmp'
GENERAL_LOG_FORMAT = (
    '%(asctime)s %(levelname)-8s %(name)s[%(process)d]: %(message)s')
GENERAL_LOG_LEVEL = 5
GENERAL_LOG_TO_SYSLOG = False
GENERAL_SERVICE_GROUP = 'filesync'
GENERAL_SERVICE_NAME = 'server'
GENERAL_SYSLOG_FORMAT = (
    '%(processName)-13s %(levelname)-8s %(name)s[%(process)d]: %(message)s')

GRAPHITE_ADMIN_PASSWORD = 'pwadmin'
GRAPHITE_ADMIN_USER = 'admin'

KEYSTONE_HOST = 'swift.local'
KEYSTONE_PORT = 0

OOPS_PATH = 'tmp/oops'

UPDOWN_PUBLIC_URL_PREFIX = 'http://some_url/p/'
UPDOWN_PUBLIC_URL_PREFIX_2 = 'http://some_url/'

S_FOUR_LOG_FILENAME = 'S4.log'
S_FOUR_STORAGEPATH = 'tmp/s4storage'

SSL_PROXY_DISABLE_SSL_COMPRESSION = True
SSL_PROXY_HEARTBEAT_INTERVAL = 5
SSL_PROXY_LOG_FILENAME = 'ssl-proxy.log'
SSL_PROXY_METRICS_NAMESPACE = 'development.filesync.ssl-proxy'
SSL_PROXY_PORT = 21101
SSL_PROXY_SERVER_NAME = 'ssl-proxy-dev'
SSL_PROXY_STATUS_PORT = 21103

STATSD_SERVERS = 'localhost:8125'

STORAGE_PROXY_PORT = None

try:
    from filesync.local_settings import *  # noqa
except ImportError:
    pass
